@@ -1,4 +1,13 @@
-#' Build package in specified directory.
+#' Build package.
+#'
+#' Building converts a package source directory into a single bundled file.
+#' If \code{binary = FALSE} this creates a \code{tar.gz} package that can
+#' be installed on any platform, provided they have a full development
+#' environment (although packages without source code can typically be
+#' install out of the box). If \code{binary = TRUE}, the package will have
+#' a platform specific extension (e.g. \code{.zip} for windows), and will
+#' only be installable on the current platform, but no development
+#' environment is needed.
 #'
 #' @param pkg package description, can be path or package name.  See
 #'   \code{\link{as.package}} for more information
@@ -8,13 +17,16 @@
 #'   \code{--no-manual --no-resave-data}) version of the package.
 #' @param vignettes For source packages: if \code{FALSE}, don't build PDF
 #'   vignettes (\code{--no-vignettes}).
+#' @param args An optional character vector of additional command
+#'   line arguments to be passed to \code{R CMD build} if \code{binary = FALSE},
+#'   or \code{R CMD install} if \code{binary = TRUE}.
 #' @param quiet if \code{TRUE} suppresses output from this function.
 #' @export
 #' @family build functions
 #' @return a string giving the location (including file name) of the built
 #'  package
 build <- function(pkg = ".", path = NULL, binary = FALSE, vignettes = TRUE,
-                  quiet = FALSE) {
+                  args = NULL, quiet = FALSE) {
   pkg <- as.package(pkg)
   if (is.null(path)) {
     path <- dirname(pkg$path)
@@ -23,26 +35,29 @@ build <- function(pkg = ".", path = NULL, binary = FALSE, vignettes = TRUE,
   compile_rcpp_attributes(pkg)
 
   if (binary) {
-    cmd <- paste("CMD INSTALL ", shQuote(pkg$path), " --build", sep = "")
+    args <- c("--build", args)
+    cmd <- paste0("CMD INSTALL ", shQuote(pkg$path), " ",
+      paste0(args, collapse = " "))
     ext <- if (.Platform$OS.type == "windows") "zip" else "tgz"
   } else {
-    args <- " --no-manual --no-resave-data"
+    args <- c(args, "--no-manual", "--no-resave-data")
 
     if (!vignettes) {
-      args <- paste(args, "--no-vignettes")
+      args <- c(args, "--no-vignettes")
 
     } else if (!nzchar(Sys.which("pdflatex"))) {
       message("pdflatex not found. Not building PDF vignettes.")
-      args <- paste(args, "--no-vignettes")
+      args <- c(args, "--no-vignettes")
     }
 
-    cmd <- paste("CMD build ", shQuote(pkg$path), args, sep = "")
+    cmd <- paste0("CMD build ", shQuote(pkg$path), " ",
+      paste0(args, collapse = " "))
 
     ext <- "tar.gz"
   }
   R(cmd, path, quiet = quiet)
 
-  targz <- paste(pkg$package, "_", pkg$version, ".", ext, sep = "")
+  targz <- paste0(pkg$package, "_", pkg$version, ".", ext)
 
   file.path(path, targz)
 }
@@ -50,10 +65,12 @@ build <- function(pkg = ".", path = NULL, binary = FALSE, vignettes = TRUE,
 
 #' Build windows binary package.
 #'
-#' Works by building source package, and then uploading to
+#' This function works by bundling source package, and then uploading to
 #' \url{http://win-builder.r-project.org/}.  Once building is complete you'll
 #' receive a link to the built package in the email address listed in the
-#' maintainer field.  It usually takes around 30 minutes.
+#' maintainer field.  It usually takes around 30 minutes. As a side effect,
+#' win-build also runs \code{R CMD check} on the package, so \code{build_win}
+#' is also useful to check that your package is ok on windows.
 #'
 #' @param pkg package description, can be path or package name.  See
 #'   \code{\link{as.package}} for more information
