@@ -3,8 +3,15 @@
 #' Uses \code{R CMD INSTALL} to install the package. Will also try to install
 #' dependencies of the package from CRAN, if they're not already installed.
 #'
-#' Installation takes place on a copy of the package produced by
-#' \code{R CMD build} to avoid modifying the local directory in any way.
+#' By default, installation takes place using the current package directory.
+#' If you have compiled code, this means that artefacts of compilation will be
+#' created in the \code{src/} directory. If you want to avoid this, you can
+#' use \code{local = FALSE} to first build a package bundle and then install
+#' it from a temporary directory. This is slower, but keeps the source
+#' directory pristine.
+#'
+#' If the package is loaded, it will be reloaded after installation. This is
+#' not always completely possible, see \code{\link{reload}} for caveats.
 #'
 #' @param pkg package description, can be path or package name.  See
 #'   \code{\link{as.package}} for more information
@@ -20,19 +27,24 @@
 #'   arguments to bew passed to \code{R CMD install}. This defaults to the
 #'   value of the option \code{"devtools.install.args"}.
 #' @param quiet if \code{TRUE} suppresses output from this function.
+#' @param dependencies \code{logical} indicating to also install uninstalled
+#'   packages which this \code{pkg} depends on/links to/suggests. See
+#'   argument \code{dependencies} of \code{\link{install.packages}}.
 #' @export
 #' @family package installation
 #' @seealso \code{\link{with_debug}} to install packages with debugging flags
 #'   set.
 #' @importFrom utils install.packages
 install <- function(pkg = ".", reload = TRUE, quick = FALSE, local = TRUE,
-                    args = getOption("devtools.install.args"), quiet = FALSE) {
+                    args = getOption("devtools.install.args"), quiet = FALSE,
+                    dependencies = NA) {
+
   pkg <- as.package(pkg)
 
   if (!quiet) message("Installing ", pkg$package)
-  install_deps(pkg)
+  install_deps(pkg, dependencies = dependencies)
 
-  # Build the package. If quick==TRUE, don't build vignettes
+  # Build the package. If quick, don't build vignettes
   if (local) {
     built_path <- pkg$path
   } else {
@@ -42,7 +54,7 @@ install <- function(pkg = ".", reload = TRUE, quick = FALSE, local = TRUE,
 
   opts <- c(
     paste("--library=", shQuote(.libPaths()[1]), sep = ""),
-    "--with-keep.source")
+    "--with-keep.source", "--install-tests")
   if (quick) {
     opts <- c(opts, "--no-docs", "--no-multiarch", "--no-demo")
   }
@@ -55,7 +67,7 @@ install <- function(pkg = ".", reload = TRUE, quick = FALSE, local = TRUE,
   invisible(TRUE)
 }
 
-install_deps <- function(pkg = ".") {
+install_deps <- function(pkg = ".", dependencies = NA) {
   pkg <- as.package(pkg)
   deps <- c(parse_deps(pkg$depends)$name, parse_deps(pkg$imports)$name,
     parse_deps(pkg$linkingto)$name)
@@ -68,7 +80,7 @@ install_deps <- function(pkg = ".") {
 
   message("Installing dependencies for ", pkg$package, ":\n",
     paste(deps, collapse = ", "))
-  install.packages(deps)
+  install.packages(deps, dependencies = dependencies)
   invisible(deps)
 }
 
